import os

WF_AUTH0_AIRTABLE_API_AUDIENCE = os.getenv(
    "WF_AUTH0_AIRTABLE_API_AUDIENCE", None)

WF_AUTH0_DOMAIN = os.getenv(
    "WF_AUTH0_DOMAIN", None)

WF_AUTH0_CLIENT_ID = os.getenv(
    "WF_AUTH0_CLIENT_ID", None)

WF_AUTH0_CLIENT_SECRET = os.getenv(
    "WF_AUTH0_CLIENT_SECRET", None)

WF_AIRTABLE_API_URL = os.getenv(
    "WF_AIRTABLE_API_URL", None)
